==> kubernetes-model-core-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeConfigStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NodeConfigStatusFluent<A extends NodeConfigStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildActive instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getActive();
    public NodeConfigSource buildActive();
    public A withActive(NodeConfigSource active);
    public Boolean hasActive();
    public NodeConfigStatusFluent.ActiveNested<A> withNewActive();
    public NodeConfigStatusFluent.ActiveNested<A> withNewActiveLike(NodeConfigSource item);
    public NodeConfigStatusFluent.ActiveNested<A> editActive();
    public NodeConfigStatusFluent.ActiveNested<A> editOrNewActive();
    public NodeConfigStatusFluent.ActiveNested<A> editOrNewActiveLike(NodeConfigSource item);
    
/**
 * This method has been deprecated, please use method buildAssigned instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getAssigned();
    public NodeConfigSource buildAssigned();
    public A withAssigned(NodeConfigSource assigned);
    public Boolean hasAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> withNewAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> withNewAssignedLike(NodeConfigSource item);
    public NodeConfigStatusFluent.AssignedNested<A> editAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> editOrNewAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> editOrNewAssignedLike(NodeConfigSource item);
    public String getError();
    public A withError(String error);
    public Boolean hasError();
    public A withNewError(String arg1);
    public A withNewError(StringBuilder arg1);
    public A withNewError(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildLastKnownGood instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getLastKnownGood();
    public NodeConfigSource buildLastKnownGood();
    public A withLastKnownGood(NodeConfigSource lastKnownGood);
    public Boolean hasLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGoodLike(NodeConfigSource item);
    public NodeConfigStatusFluent.LastKnownGoodNested<A> editLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGoodLike(NodeConfigSource item);
    public interface ActiveNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<NodeConfigStatusFluent.ActiveNested<N>> {

        public N and();
        public N endActive();    }


    public interface AssignedNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<NodeConfigStatusFluent.AssignedNested<N>> {

        public N and();
        public N endAssigned();    }


    public interface LastKnownGoodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<NodeConfigStatusFluent.LastKnownGoodNested<N>> {

        public N and();
        public N endLastKnownGood();    }


}

==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeConfigStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NodeConfigStatusFluent<A extends NodeConfigStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildActive instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getActive();
    public NodeConfigSource buildActive();
    public A withActive(NodeConfigSource active);
    public Boolean hasActive();
    public NodeConfigStatusFluent.ActiveNested<A> withNewActive();
    public NodeConfigStatusFluent.ActiveNested<A> withNewActiveLike(NodeConfigSource item);
    public NodeConfigStatusFluent.ActiveNested<A> editActive();
    public NodeConfigStatusFluent.ActiveNested<A> editOrNewActive();
    public NodeConfigStatusFluent.ActiveNested<A> editOrNewActiveLike(NodeConfigSource item);
    
/**
 * This method has been deprecated, please use method buildAssigned instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getAssigned();
    public NodeConfigSource buildAssigned();
    public A withAssigned(NodeConfigSource assigned);
    public Boolean hasAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> withNewAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> withNewAssignedLike(NodeConfigSource item);
    public NodeConfigStatusFluent.AssignedNested<A> editAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> editOrNewAssigned();
    public NodeConfigStatusFluent.AssignedNested<A> editOrNewAssignedLike(NodeConfigSource item);
    public String getError();
    public A withError(String error);
    public Boolean hasError();
    public A withNewError(StringBuilder arg1);
    public A withNewError(int[] arg1,int arg2,int arg3);
    public A withNewError(char[] arg1);
    public A withNewError(StringBuffer arg1);
    public A withNewError(byte[] arg1,int arg2);
    public A withNewError(byte[] arg1);
    public A withNewError(char[] arg1,int arg2,int arg3);
    public A withNewError(byte[] arg1,int arg2,int arg3);
    public A withNewError(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewError(String arg1);
    
/**
 * This method has been deprecated, please use method buildLastKnownGood instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getLastKnownGood();
    public NodeConfigSource buildLastKnownGood();
    public A withLastKnownGood(NodeConfigSource lastKnownGood);
    public Boolean hasLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGoodLike(NodeConfigSource item);
    public NodeConfigStatusFluent.LastKnownGoodNested<A> editLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGood();
    public NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGoodLike(NodeConfigSource item);
    public interface ActiveNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<NodeConfigStatusFluent.ActiveNested<N>> {

            public N and();
            public N endActive();    }


    public interface AssignedNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<NodeConfigStatusFluent.AssignedNested<N>> {

            public N and();
            public N endAssigned();    }


    public interface LastKnownGoodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<NodeConfigStatusFluent.LastKnownGoodNested<N>> {

            public N and();
            public N endLastKnownGood();    }


}
